@@ -345,8 +345,9 @@ class TimestreamLoader(TimestreamReader):
                         k:v
                     })
             elif type(v) is str:
-                # Strings get converted into dimensions
-                dimensions.add_dimension(k, v)
+                # Strings get converted into dimensions. Ignore empty strings
+                if v.strip():
+                    dimensions.add_dimension(k, v)
             else:
                 msg = f'Could not create a record or dimension from type "{type(v)}" at key {k}'
                 if not ignore_parse_error:
